@@ -20,6 +20,9 @@ module.exports = {
   errorBadRequest: function (res) {
     responseError(res, '400', 'Bad Request', 'something not right.')
   },
+  errorConflict: function (res) {
+    responseError(res, '409', 'Conflict', 'This note already exists.')
+  },
   errorTooLong: function (res) {
     responseError(res, '413', 'Payload Too Large', 'Shorten your note!')
   },
