@@ -5,7 +5,7 @@ exports.isSQLite = function isSQLite (sequelize) {
 }
 
 exports.getImageMimeType = function getImageMimeType (imagePath) {
-  var fileExtension = /[^.]+$/.exec(imagePath)
+  const fileExtension = /[^.]+$/.exec(imagePath)
 
   switch (fileExtension[0].toLowerCase()) {
     case 'bmp':
@@ -25,3 +25,12 @@ exports.getImageMimeType = function getImageMimeType (imagePath) {
       return undefined
   }
 }
+
+exports.useUnless = function excludeRoute (paths, middleware) {
+  return function (req, res, next) {
+    if (paths.includes(req.path)) {
+      return next()
+    }
+    return middleware(req, res, next)
+  }
+}
